<div class="modal fade" id="{{ name }}Modal" tabindex="-1" role="dialog"
     aria-labelledby="modalLabel{{ name }}"
     aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <form ng-submit="modal.confirm(name)">
                <div class="modal-header">
                    <h5 class="modal-title" id="modalLabel{{ name }}">{{ title }}</h5>
                    <button class="close" type="button" data-dismiss="modal"
                            aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <ng-transclude></ng-transclude>
                    <p ng-show="modal.error[name]" style="color: red;">Error: {{ modal.error[name] }}</p>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" type="button" data-dismiss="modal">
                        {{ no || "No" }}
                    </button>
                    <button type="submit" class="btn btn-primary">
                        {{ yes || "Yes" }}
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>