{% extends "fmd_base.html" %} {% block body %}

<body>
  <div class="container py-5">
    {% if show_login_banner %}
    <div class="row">
      <div class="col-md-8 offset-md-2">
        <div class="text-center" style="margin-bottom: 20px; margin-top: -30px">
          <div style="text-align: center">
            <img
              src="{{ url_for(blueprint_name + '.static', filename='img/header.png') }}"
              width="80%"
            />
          </div>
          <span
            >Automatically monitor the evolving performance of Flask/Python web
            services</span
          >
        </div>
      </div>
    </div>
    {% endif %}

    <div class="row">
      <div class="col-md-4 offset-md-4">
        <span class="anchor" id="formLogin"></span>
        <div class="card card-outline-secondary">
          <div class="card-header">
            <h5>Login</h5>
          </div>

          <div class="card-body">
            <form class="form" method="POST" action="login">
              <div class="form-group">
                <label for="formName"><i class="fa fa-user"></i> Login</label>
                <input
                  id="formName"
                  name="name"
                  type="text"
                  class="form-control"
                  placeholder="Username"
                  autofocus
                  required
                />
              </div>

              <div class="form-group">
                <label for="formPassword"
                  ><i class="fa fa-lock"></i> Password</label
                >
                <input
                  name="password"
                  type="password"
                  class="form-control"
                  placeholder="Password"
                  required
                />
              </div>

              <button name="Login" class="btn btn-primary btn-block">
                Login
              </button>
            </form>
            <hr />
            {% if show_login_footer %}
            <div class="text-center">
              For advanced documentation, see
              <a
                target="_blank"
                href="http://flask-monitoringdashboard.readthedocs.io"
                >this site</a
              >
            </div>
            {% endif %}
          </div>
        </div>
      </div>
    </div>
  </div>
</body>
{% endblock %}
